@@ -47,40 +47,26 @@ YACReader::WhatsNewDialog::WhatsNewDialog(QWidget *parent)
 
     auto text = new QLabel();
     text->setText("New release with the following updates:<br/>"
-                  "<br/>"
-                  "9.9.2 includes notarized builds for macos and codesigned builds for windows. It also gets new builds using Qt6.<br/>"
                   "<br/>"
                   "<span style=\"font-weight:600\">YACReader</span><br/>"
-                  "   &#8226; Show error when opening bad open recent entries.<br/>"
-                  "   &#8226; GoTo page: Fix segfault when entering page numbers greater than comic's page count(toolbar and page flow).<br/>"
-                  "   &#8226; Initialize GotoFlow on current page, not cover.<br/>"
-                  "   &#8226; GotoFlow with Quick navigation mode: Fix page index error when using both mouse and keyboard for navigation.<br/>"
-                  "   &#8226; Support HDPI screens.<br/>"
-                  "   &#8226; Use one wheel mouse step per page in full page mode.<br/>"
-                  "   &#8226; (Linux) Add updated MIME types to .desktop file for .cbz and .cbr.<br/>"
-                  "   &#8226; New settings to control page turning behaviour on scroll.<br/>"
-                  "   &#8226; Make forward and backward buttons in a mouse turn pages.<br/>"
-                  "   &#8226; Don't crash if bookmarks get corrupt for some reason.<br/>"
-                  "   &#8226; Magnifying glass fixes and improvements.<br/>"
+                  "   &#8226; Fixed color selection dialog appearing as a subwindow in macos.<br/>"
+                  "   &#8226; Better support for HDPI screens (SVG icons).<br/>"
                   "<br/>"
                   "<span style=\"font-weight:600\">YACReaderLibrary</span><br/>"
-                  "   &#8226; Support HDPI screens. <br/>"
-                  "   &#8226; Support import legacy XML info in comic files.<br/>"
-                  "   &#8226; Enable arrow keys navigation in the folders tree view.<br/>"
-                  "   &#8226; Add `Publication Date` column to the comics table view.<br/>"
-                  "   &#8226; Use a scale effect in the comics grids on mouse over.<br/>"
-                  "   &#8226; Fix selection when clicking on a folder in search mode.<br/>"
-                  "   &#8226; Add system info to the help/about dialog to help reporting bugs.<br/>"
-                  "   &#8226; Fix defaul value for manga/comic mode in folders.<br/>"
-                  "   &#8226; Add an edit for filtering series results returned by Comic Vine.<br/>"
-                  "   &#8226; Support editing comics tags sequentially without leaving the edit dialog.<br/>"
-                  "   &#8226; Fix export/import comics info.<br/>"
-                  "   &#8226; Fix potential infinite loop/crash on library updates (NEW in 9.9.2).<br/>"
-                  "   &#8226; Fix comic properties dialog sizing (NEW in 9.9.2).<br/>"
-                  "   &#8226; Fixes and stability improvements, specially in Qt6 builds (NEW in 9.9.2).<br/>"
+                  "   &#8226; New folder content view that replaces the old `subfolders in this folder` view shown when folders don't have direct comics. You may need to update your libraries to make folders display properly.<br/>"
+                  "   &#8226; Continue Reading view that it is shown for the root folder.<br/>"
+                  "   &#8226; UI gets updated when YACReaderLibrary gets updates from YACReader or YACReader for iOS.<br/>"
+                  "   &#8226; Fixed going forward history navigation.<br/>"
+                  "   &#8226; Fixed selected folder restoration after folder updates.<br/>"
+                  "   &#8226; Add option to delete metadata from comics.<br/>"
+                  "   &#8226; Better support for HDPI screens (SVG icons).<br/>"
+                  "   &#8226; Importing ComicInfo.XML is now optional, you can change the behavior in Settings -> General.<br/>"
+                  "   &#8226; Add option to scan XML metadata from all the comics in a folder.<br/>"
                   "<br/>"
                   "<span style=\"font-weight:600\">Server</span><br/>"
-                  "   &#8226; Always serve a cover image to the iOS client for any folder that has content (requeries a library content update). <br/>"
+                  "   &#8226; New webui status page (reachable by navigating to server::port/webui).<br/>"
+                  "<br/>"
+                  "NOTE: Importing metadata from ComicInfo.XML in now disabled by default, if you want you can enable it Settings -> General.<br/>"
                   "<br/>"
                   "I hope you enjoy the new update. Please, if you like YACReader consider to become a patron in <a href=\"https://www.patreon.com/yacreader\" style=\"color:#E8B800;\">Patreon</a> or donate some money using <a href=\"https://www.paypal.com/donate?business=5TAMNQCDDMVP8&item_name=Support+YACReader\" style=\"color:#E8B800;\">Pay-Pal</a> and help keeping the project alive. Remember that there is an iOS version available in the <a href=\"https://apps.apple.com/app/id635717885\" style=\"color:#E8B800;\">Apple App Store</a>.");
     QFont textLabelFont("Arial", 15, QFont::Light);
